@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class LbHealthCheckConfig(AppConfig):
-    name = 'lb_health_check'
+    name = "lb_health_check"
